==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/mk.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерија",
    "New" : "Ново",
    "Error loading slideshow template" : "Грешка при вчитувањето на шаблонот за прикажување на слајдови",
    "Next" : "Следно",
    "Play" : "Пушти",
    "Pause" : "Пауза",
    "Previous" : "Претходно",
    "Close" : "Затвори",
    "Download" : "Преземи",
    "Delete" : "Избриши",
    "Share" : "Сподели",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "Upload" : "Префрли",
    "Error" : "Грешка",
    "Error while sharing" : "Грешка при споделување",
    "Error while unsharing" : "Грешка при прекин на споделување",
    "Error while changing permissions" : "Грешка при промена на привилегии",
    "Shared with you and the group {group} by {owner}" : "Споделено со Вас и групата {group} од {owner}",
    "Shared with you by {owner}" : "Споделено со Вас од {owner}",
    "Share with users or groups …" : "Сподели со корисници или групи ...",
    "Share with users, groups or remote users …" : "Споделено со корисници, групи или оддалечени корисници ...",
    "Share link" : "Сподели ја врската",
    "Link" : "Линк",
    "Password protect" : "Заштити со лозинка",
    "Password" : "Лозинка",
    "Choose a password for the public link" : "Одбери лозинка за јавниот линк",
    "Allow editing" : "Овозможи уредување",
    "Email link to person" : "Прати врска по е-пошта на личност",
    "Send" : "Прати",
    "Set expiration date" : "Постави рок на траење",
    "Expiration" : "Истекување",
    "Expiration date" : "Рок на траење",
    "An error occured. Please try again" : "Се случи грешка. Обиди се повторно",
    "Adding user..." : "Додади корисник...",
    "group" : "група",
    "remote" : "далечински",
    "Resharing is not allowed" : "Повторно споделување не е дозволено",
    "Unshare" : "Не споделувај",
    "notify by email" : "извести преку електронска пошта",
    "can share" : "може да споделува",
    "can edit" : "може да се измени",
    "access control" : "контрола на пристап",
    "create" : "креирај",
    "change" : "промени",
    "delete" : "избриши",
    "Password protected" : "Заштитено со лозинка",
    "Error unsetting expiration date" : "Грешка при тргање на рокот на траење",
    "Error setting expiration date" : "Грешка при поставување на рок на траење",
    "Sending ..." : "Праќање...",
    "Email sent" : "Е-порака пратена",
    "Warning" : "Предупредување",
    "This share is password-protected" : "Ова споделување е заштитено со лозинка",
    "The password is wrong. Try again." : "Лозинката е грешна. Обиди се повторно.",
    "Cancel upload" : "Откажи прикачување",
    "Reasons might be:" : "Причината може да биде:",
    "the item was removed" : "предметот беше одстранет",
    "sharing is disabled" : "споделувањето не е дозволено"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-13.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/mk.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерија",
    "New" : "Ново",
    "Error loading slideshow template" : "Грешка при вчитувањето на шаблонот за прикажување на слајдови",
    "Next" : "Следно",
    "Play" : "Пушти",
    "Pause" : "Пауза",
    "Previous" : "Претходно",
    "Close" : "Затвори",
    "Download" : "Преземи",
    "Delete" : "Избриши",
    "Share" : "Сподели",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "Upload" : "Префрли",
    "Error" : "Грешка",
    "Error while sharing" : "Грешка при споделување",
    "Error while unsharing" : "Грешка при прекин на споделување",
    "Error while changing permissions" : "Грешка при промена на привилегии",
    "Shared with you and the group {group} by {owner}" : "Споделено со Вас и групата {group} од {owner}",
    "Shared with you by {owner}" : "Споделено со Вас од {owner}",
    "Share with users or groups …" : "Сподели со корисници или групи ...",
    "Share with users, groups or remote users …" : "Споделено со корисници, групи или оддалечени корисници ...",
    "Share link" : "Сподели ја врската",
    "Link" : "Линк",
    "Password protect" : "Заштити со лозинка",
    "Password" : "Лозинка",
    "Choose a password for the public link" : "Одбери лозинка за јавниот линк",
    "Allow editing" : "Овозможи уредување",
    "Email link to person" : "Прати врска по е-пошта на личност",
    "Send" : "Прати",
    "Set expiration date" : "Постави рок на траење",
    "Expiration" : "Истекување",
    "Expiration date" : "Рок на траење",
    "An error occured. Please try again" : "Се случи грешка. Обиди се повторно",
    "Adding user..." : "Додади корисник...",
    "group" : "група",
    "remote" : "далечински",
    "Resharing is not allowed" : "Повторно споделување не е дозволено",
    "Unshare" : "Не споделувај",
    "notify by email" : "извести преку електронска пошта",
    "can share" : "може да споделува",
    "can edit" : "може да се измени",
    "access control" : "контрола на пристап",
    "create" : "креирај",
    "change" : "промени",
    "delete" : "избриши",
    "Password protected" : "Заштитено со лозинка",
    "Error unsetting expiration date" : "Грешка при тргање на рокот на траење",
    "Error setting expiration date" : "Грешка при поставување на рок на траење",
    "Email sent" : "Е-порака пратена",
    "Warning" : "Предупредување",
    "This share is password-protected" : "Ова споделување е заштитено со лозинка",
    "The password is wrong. Try again." : "Лозинката е грешна. Обиди се повторно.",
    "Cancel upload" : "Откажи прикачување",
    "Reasons might be:" : "Причината може да биде:",
    "the item was removed" : "предметот беше одстранет",
    "sharing is disabled" : "споделувањето не е дозволено",
    "Sending ..." : "Праќање..."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
